/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.grizzly.scripting.pool;

/*
 * An interface that describes functions to assist the DynamicPool
 * A PoolAdapter will implement runtime-specific methods for initialization, cleanup, and validation of objects in a pool
 */

public interface PoolAdapter<T> {

    /**
     * initializeObject returns a newly-created Object, ready to be added to the pool
     * All needed configuration should be done here.
     * @return The new runtime
     */
    public T initializeObject();

    /**
     * dispose should do any needed cleanup to the object to ensure clean shutdown of the object: closing input streams, releasing resources, etc.
     * @param dead The dead object to be disposed of
     */
    public void dispose(T dead);

    /**
     * Validate will check a newly-returned object to ensure that it is in a suitable state to be re-added to the pool.
     * Implementations where object state is unimportant can simply return true. If desired, the validate method may also
     * attempt to fix invalid objects and return true if that succeeds.
     * @param toCheck The object to validate
     * @return true if the object is valid, false otherwise.
     */
    public boolean validate(T toCheck);
}
